@@ -3,7 +3,7 @@ package App::ZofCMS::Plugin::ConfigToTemplate;
 use warnings;
 use strict;
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use base 'App::ZofCMS::Plugin::Base';
 
@@ -42,7 +42,11 @@ sub _do {
             $t->{ $cell }{ $_ } = $zcms_config->{ $ccell }{ $_ };
         }
     }
-}
+};
+
+__END__
+
+=encoding utf8
 
 =head1 NAME
 
